This function derives additional parameters for latent change score models. In particular, it specifies the means and variances of interval-specific slopes, interval-specific changes, and values of change- from-baseline.
getUNI.addpara(
dat,
curveFun,
intrinsic = NULL,
t_var,
records,
growth_TIC,
decompose,
starts
)A list containing the specification of the means and variances of interval-specific slopes, interval-specific changes, and values of change-from-baseline for latent change score models.
A wide-format data frame, with each row corresponding to a unique ID. It contains the observed variables
with repeated measurements and occasions, and time-invariant covariates (TICs) if any. It takes the value passed from
getLCSM() or getTVCmodel().
A string specifying the functional form of the growth curve. Supported options for latent change score
models include: "quadratic" (or "QUAD"), "negative exponential" (or "EXP"), "Jenss-Bayley"
(or "JB"), and "nonparametric" (or "NonP"). It takes the value passed from getLCSM() or
getTVCmodel().
A logical flag indicating whether to build an intrinsically nonlinear longitudinal model. It takes the
value passed from getLCSM() or getTVCmodel().
A string specifying the prefix of the column names corresponding to the time variable at each study wave.
It takes the value passed from getLCSM() or getTVCmodel().
A numeric vector specifying indices of the study waves. It takes the value passed from getLCSM()
or getTVCmodel().
A string or character vector specifying the column name(s) of time-invariant covariate(s) contributing
to the variability of growth factors if any. It takes the value passed from getLCSM() or getTVCmodel().
An integer specifying the decomposition option for temporal states. Supported values include 0 (no
decomposition), 1 (decomposition with interval-specific slopes as temporal states), 2 (decomposition with
interval-specific changes as temporal states), and 3 (decomposition with change-from-baseline as temporal states).
It takes the value passed from getTVCmodel(). The argument is set as NULL when fitting a latent change score
model.
A list containing initial values for the parameters, either takes the value passed from getLCSM() or
getTVCmodel(), or derived by the helper function getUNI.initial() or getTVC.initial().